==> google_applovin_unity_ads-1.1.3.tar.gz: lib/native/controller.dart <==
import 'dart:async';
import 'dart:ui';

import 'package:flutter/services.dart';
import 'package:google_applovin_unity_ads/google_applovin_unity_ads.dart';

import '../utils.dart';

enum NativeAdEvent {
  /// Called when an impression is recorded for an ad.
  impression,

  /// Called when an ad request failed.
  loadFailed,

  /// Called when an ad is received.
  loaded,

  /// Called when the ad starts loading
  loading,
}

class NativeSize {
  /// The Size of the Banner.
  final Size size;

  const NativeSize(this.size);

  // static const NativeSize SMALL_NATIVE = NativeSize(Size(double.infinity, 100));
  //
  // static const NativeSize MEDIUM_NATIVE = NativeSize(Size(double.infinity, 170));
  //
  // static const NativeSize FULL_NATIVE = NativeSize(Size(double.infinity, 360));

  @override
  String toString() => '${size.width}x${size.height}';
}

class NativeAdController extends LoadShowAd<NativeAdEvent>
    with AttachableMixin {
  Stream<Map<NativeAdEvent, dynamic>> get onEvent => super.onEvent;

  /// Creates a new native ad controller
  NativeAdController({
    Duration loadTimeout = kDefaultLoadTimeout,
    Duration timeout = kDefaultAdTimeout,
  }) : super(
          loadTimeout: loadTimeout,
          timeout: timeout,
        );

  void init() {
    channel.setMethodCallHandler(_handleMessages);
    GoogleApplovinUnityAds.platform.invokeMethod('call.ads.native', {'id': id});
  }

  void dispose() {
    super.dispose();
    GoogleApplovinUnityAds.platform.invokeMethod('dispose.ads.native', {
      'id': id,
    });
    attach(false);
  }

  Future<dynamic> _handleMessages(MethodCall call) async {
    if (isDisposed) return;
    switch (call.method) {
      case 'loading':
        isLoaded = false;
        onEventController.add({NativeAdEvent.loading: null});
        break;
      case 'onAdFailedToLoad':
        isLoaded = false;
        onEventController.add({
          NativeAdEvent.loadFailed: AdError.fromJson(call.arguments),
        });
        break;
      case 'onAdLoaded':
        isLoaded = true;
        onEventController.add({NativeAdEvent.loaded: call.arguments});
        break;
      case 'onAdImpression':
        onEventController.add({NativeAdEvent.impression: null});
        break;
      default:
        break;
    }
  }

  Future<bool> load({
    bool force = false,
    Duration? timeout,
  }) async {
    ensureAdNotDisposed();
    // assertMobileAdsIsInitialized();
    if (!debugCheckAdWillReload(isLoaded, force)) return false;
    isLoaded = (await channel.invokeMethod<bool>('load.ads.native').timeout(
      timeout ?? loadTimeout,
      onTimeout: () {
        if (!onEventController.isClosed && !isLoaded) {
          onEventController.add({
            NativeAdEvent.loadFailed: AdError.timeoutError,
          });
        }
        return false;
      },
    ))!;
    if (isLoaded) lastLoadedTime = DateTime.now();
    return isLoaded;
  }
}

==> google_applovin_unity_ads-1.1.7.tar.gz: lib/native/controller.dart <==
import 'dart:async';
import 'dart:ui';

import 'package:flutter/services.dart';
import 'package:google_applovin_unity_ads/google_applovin_unity_ads.dart';

import '../utils.dart';

enum NativeAdEvent {
  /// Called when an impression is recorded for an ad.
  impression,

  /// Called when an ad request failed.
  loadFailed,

  /// Called when an ad is received.
  loaded,

  /// Called when the ad starts loading
  loading,
}

class NativeSize {
  /// The Size of the Banner.
  final Size size;

  const NativeSize(this.size);

  // static const NativeSize SMALL_NATIVE = NativeSize(Size(double.infinity, 100));
  //
  // static const NativeSize MEDIUM_NATIVE = NativeSize(Size(double.infinity, 170));
  //
  // static const NativeSize FULL_NATIVE = NativeSize(Size(double.infinity, 360));

  @override
  String toString() => '${size.width}x${size.height}';
}

class NativeAdController extends LoadShowAd<NativeAdEvent>
    with AttachableMixin {
  Stream<Map<NativeAdEvent, dynamic>> get onEvent => super.onEvent;
  final _platform = const MethodChannel('dev.bitcoding.ads/native');
  /// Creates a new native ad controller
  NativeAdController({
    Duration loadTimeout = kDefaultLoadTimeout,
    Duration timeout = kDefaultAdTimeout,
  }) : super(
          loadTimeout: loadTimeout,
          timeout: timeout,
        );

  void init() {
    channel.setMethodCallHandler(_handleMessages);
    _platform.invokeMethod('call.ads.native', {'id': id});
  }

  void dispose() {
    super.dispose();
    _platform.invokeMethod('dispose.ads.native', {
      'id': id,
    });
    attach(false);
  }

  Future<dynamic> _handleMessages(MethodCall call) async {
    if (isDisposed) return;
    switch (call.method) {
      case 'loading':
        isLoaded = false;
        onEventController.add({NativeAdEvent.loading: null});
        break;
      case 'onAdFailedToLoad':
        isLoaded = false;
        onEventController.add({
          NativeAdEvent.loadFailed: AdError.fromJson(call.arguments),
        });
        break;
      case 'onAdLoaded':
        isLoaded = true;
        onEventController.add({NativeAdEvent.loaded: call.arguments});
        break;
      case 'onAdImpression':
        onEventController.add({NativeAdEvent.impression: null});
        break;
      default:
        break;
    }
  }

  Future<bool> load({
    bool force = false,
    Duration? timeout,
  }) async {
    ensureAdNotDisposed();
    // assertMobileAdsIsInitialized();
    if (!debugCheckAdWillReload(isLoaded, force)) return false;
    isLoaded = (await channel.invokeMethod<bool>('load.ads.native').timeout(
      timeout ?? loadTimeout,
      onTimeout: () {
        if (!onEventController.isClosed && !isLoaded) {
          onEventController.add({
            NativeAdEvent.loadFailed: AdError.timeoutError,
          });
        }
        return false;
      },
    ))!;
    if (isLoaded) lastLoadedTime = DateTime.now();
    return isLoaded;
  }
}
